/*
Sample project for BPNGOnlineStreamingLib (blue PiraT 2 Onlinestreaming Library)
*/
#include <iostream>
#include <conio.h>

#include "DataStreamingListener.h"
#include "IBPNGStreaming.h"
#include "BPNGDefines.h"

#include <time.h>

using namespace std;

int main()
{   
    // 1. Set logger IP address
    const string ipAdress = "10.64.76.5";

    // 2. Create onlinestreaming interface
    int timeOutInMilliSec = 0;
    IBPNGStreaming* streaming = getBPNGStreamingInterface(timeOutInMilliSec, true);
    if (!streaming)
    {
        cout << "Failed to create pointer to OnlineStreamingInterface" << endl;
        return -1;
    }

    // 3. Create data streaming listener
    bool writeDataToFile = false;
    DataStreamingListener dataStreamListener(writeDataToFile);
    streaming->addStreamingListener((IBPNGStreamingListener*)&dataStreamListener);

    // 4. Disconnect interface from logger
    if (!streaming->connectLogger(ipAdress.c_str(), false))
    {
        releaseBPNGStreamingInterface(streaming);
        return -1;
    }

	// 5. Select channels you want to stream
    IChannelList* channelList = streaming->getChannelList();
    if(channelList->getSize() == 0)
    {
        cout << "Did not receive list of streaming channels from interface" << endl;
        releaseBPNGStreamingInterface(streaming);
        return -1;
    }

    for (unsigned int i = 0; i < channelList->getSize(); i++)
    {
        const IChannel* channel = channelList->getChannel(i);
        // e.g. only select channel CAN #1. Note that channel index always start at zero
        if (channel->getType() == CH_ANALOG_IN && channel->getIndex() == 0)
        {
            streaming->setChannelFilter(channel->getType(), channel->getIndex(), true);
        }
    }

    cout << "Press any key to start streaming" << endl;
    _getch();
    time_t now = time(0);
    cout << "Started at " << asctime(gmtime(&now)) << endl;

    // 6. Start streaming data
    if(!streaming->startDataStreaming())
    {
        BPNGError err = streaming->getLastError();
        cout << err.msg << endl;
        releaseBPNGStreamingInterface(streaming);
        return -1;
    }

    cout << "Press any key to stop streaming" << endl;
    _getch();

    // 7. Stop streaming data
    if(!streaming->stopDataStreaming())
    {
        BPNGError err = streaming->getLastError();
        cout << err.code << endl;
        cout << err.msg << endl;
        releaseBPNGStreamingInterface(streaming);
        return -1;
    }

    // 9. Disconnect interface from logger
    streaming->disconnectLogger();
    releaseBPNGStreamingInterface(streaming);
    cout << "Streaming stopped, logger disconnected" << endl;
    cout << "Good bye (press any key)" << endl;
    _getch();
    return 0;
}
